@@ -16,7 +16,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  * 
  * Linking this library statically or dynamically with other modules is
  * making a combined work based on this library.  Thus, the terms and
@@ -257,13 +257,13 @@ public class FTPConnection
         socket.setSoTimeout(timeout);
       }
     
-    InputStream in = socket.getInputStream();
-    in = new BufferedInputStream(in);
-    in = new CRLFInputStream(in);
-    this.in = new LineInputStream(in);
-    OutputStream out = socket.getOutputStream();
-    out = new BufferedOutputStream(out);
-    this.out = new CRLFOutputStream(out);
+    InputStream is = socket.getInputStream();
+    is = new BufferedInputStream(is);
+    is = new CRLFInputStream(is);
+    in = new LineInputStream(is);
+    OutputStream os = socket.getOutputStream();
+    os = new BufferedOutputStream(os);
+    out = new CRLFOutputStream(os);
     
     // Read greeting
     FTPResponse response = getResponse();
@@ -405,13 +405,13 @@ public class FTPConnection
         if (confidential)
           {
             // Set up streams
-            InputStream in = ss.getInputStream();
-            in = new BufferedInputStream(in);
-            in = new CRLFInputStream(in);
-            this.in = new LineInputStream(in);
-            OutputStream out = ss.getOutputStream();
-            out = new BufferedOutputStream(out);
-            this.out = new CRLFOutputStream(out);
+            InputStream is = ss.getInputStream();
+            is = new BufferedInputStream(is);
+            is = new CRLFInputStream(is);
+            in = new LineInputStream(is);
+            OutputStream os = ss.getOutputStream();
+            os = new BufferedOutputStream(os);
+            out = new CRLFOutputStream(os);
           }
         return true;
       }
@@ -1157,10 +1157,10 @@ public class FTPConnection
       {
       case 125:                  // Data connection already open; transfer starting
       case 150:                  // File status okay; about to open data connection
-        InputStream in = dtp.getInputStream();
-        in = new BufferedInputStream(in);
-        in = new CRLFInputStream(in);     // TODO ensure that TYPE is correct
-        LineInputStream li = new LineInputStream(in);
+        InputStream is = dtp.getInputStream();
+        is = new BufferedInputStream(is);
+        is = new CRLFInputStream(is);     // TODO ensure that TYPE is correct
+        LineInputStream li = new LineInputStream(is);
         List ret = new ArrayList();
         for (String line = li.readLine();
              line != null;
